package Test::Synopsis::__TestBait_NoPod;

# Dummy module used during testing of Test::Synopsis. Needs to be in the lib/
# dir of the Test-Synopsis distribution to Test::Synopsis can find it.
#
# This module does not have a POD section at all; Test::Synopsis still
# shouldn't warn even with -w.

use strict;
use warnings;

# VERSION

1;
