package Test::Synopsis::__TestBait_BrokenSYNOPSIS01;

# Used by 01-fail-if-SYNOPSIS-has-errors.t

use strict;
use warnings;

# VERSION

1;

=pod

=head1 SYNOPSIS

    print "Foos!\n";

    $x; # undeclared

=head1 DESCRIPTION

bleh

=cut
