package Test::Synopsis::__TestBait_Test04HEREDOC;
# Dummy module used during testing of Test::Synopsis

use strict;
use warnings;

# VERSION

1;

=pod

=head1 SYNOPSIS

Testing stuff:

    my $x = <<'END';
        blargs
    END

=cut
