package Test::Synopsis::__TestBait_Test03;
# Dummy module used during testing of Test::Synopsis

use strict;
use warnings;

# VERSION

1;

=pod

=head1 SYNOPSIS

Testing stuff:

    BEGIN { our $Foo = 42; }

    sub foobar { return 1; }

=cut
