package Test::Synopsis::__TestBait_Test10InPodSkipWithBegin;
# Dummy module used during testing of Test::Synopsis

use strict;
use warnings;

# VERSION

1;

=pod

=head1 SYNOPSIS

=for test_synopsis BEGIN { die "SKIP: testing skipping stuff \\o/\n"; }

    $x;

=cut
