use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Clement
Dave
Doherty
Greg
Grünauer
Kevin
Marcel
Mengué
Mike
Miyagawa
Mullane
Olivier
Patrice
Rolsky
Ryde
Sabino
Synopsis
Tatsuhiko
Test
Znet
Zoffix
autarch
doherty
dolmen
kryde
lib
marcel
miyagawa
monsieurp
turnstep
zoffix
