package Test::Synopsis::__TestBait_TestMultipleChunks;
# Dummy module used during testing of Test::Synopsis

use strict;
use warnings;

# VERSION

1;

=pod

=head1 SYNOPSIS

=for test_synopsis use warnings FATAL => 'all';

First sample code:

    my $x = 42;
    my $secondline = 1;

    my $fourthline = 4;

Second sample code:

    my $x = 43;

    my $fourthline = 0;
    bob;

=head1 DESCRIPTION

bleh

=cut
